@@ -18,6 +18,7 @@ __all__ = [
     "deliver_forward_reference",
     "PromisedList",
     "PromisedTuple",
+    "PromisedDict",
     "ptype",
     "TypeType",
     "is_object",
@@ -57,6 +58,10 @@ class AbstractType(metaclass=TypeMeta):
         """Boolean that indicates whether this is or contains a parametric
         type."""
 
+    @property
+    def runtime_type_of(self):
+        return False
+
 
 class VarArgs(AbstractType):
     """Plum type that represents a variable number of the same Plum type.
@@ -221,6 +226,11 @@ class Type(ComparableType):
         # `_is_parametric` with the value `True`.
         return hasattr(self._type, "_is_parametric") and self._type._is_parametric
 
+    @property
+    def runtime_type_of(self):
+        # Types don't specify `runtime_type_of` except for custom Plum types.
+        return hasattr(self._type, "runtime_type_of") and self._type.runtime_type_of
+
 
 class ResolvableType(ComparableType, Resolvable):
     """A resolvable Plum type."""
@@ -229,7 +239,10 @@ class ResolvableType(ComparableType, Resolvable):
         return hash(ptype(self.resolve()))
 
     def __repr__(self):
-        return repr(ptype(self.resolve()))
+        if self.resolved:
+            return repr(ptype(self.resolve()))
+        else:
+            return "<ResolvableType: unresolved>"
 
     def get_types(self):
         return ptype(self.resolve()).get_types()
@@ -289,9 +302,16 @@ class ForwardReferencedType(PromisedType):
         self.name = name
         PromisedType.__init__(self)
 
+    def __repr__(self):
+        if self.resolved:
+            return super().__repr__()
+        else:
+            return f"ForwardReferencedType(name={self.name!r})"
+
 
 PromisedList = Promise()  # This will resolve to `.parametric.List`.
 PromisedTuple = Promise()  # This will resolve to `.parametric.Tuple`.
+PromisedDict = Promise()  # This will resolve to `.parametric.Dict`.
 
 
 def ptype(obj):
@@ -341,6 +361,11 @@ def ptype(obj):
                 return PromisedTuple.resolve()(*(ptype(t) for t in obj.__args__))
             else:
                 return Type(tuple)
+        elif obj_str == "Dict":
+            if obj_is_parametrised:
+                return PromisedDict.resolve()(*(ptype(t) for t in obj.__args__))
+            else:
+                return Type(dict)
         elif obj_str == "ForwardRef" or obj_str == "_ForwardRef":
             # This depends on the implementation below!
             obj = obj.__forward_arg__
@@ -350,7 +375,7 @@ def ptype(obj):
             return Type(obj)
         else:
             raise NotImplementedError(
-                f'There is currently no support for "typing.{obj.__name__}". '
+                f'There is currently no support for "{obj}". '
                 f"Please open an issue at https://github.com/wesselb/plum/issues"
             )  # pragma: no cover
 
@@ -362,11 +387,14 @@ def ptype(obj):
     if isinstance(obj, type):
         return Type(obj)
 
+    if obj is None:
+        return Type(type(None))
+
     raise RuntimeError(f'Could not convert "{obj}" to a type.')
 
 
 TypeType = Union[type, AbstractType]
-"""ptype: The type of a Plum type, including shorthands."""
+"""ptype: The type of a type or Plum type."""
 
 
 def is_object(t):
